@@ -50,6 +50,8 @@
 #define CONFIG_CPM2		1	/* has CPM2			*/
 #endif
 
+#define CONFIG_FSL_LAW		1	/* Use common FSL init code */
+
 /*
  * sysclk for MPC85xx
  *
@@ -417,13 +419,6 @@
  */
 #define CFG_BOOTMAPSZ	(8 << 20)	/* Initial Memory map for Linux	*/
 
-/* Cache Configuration */
-#define CFG_DCACHE_SIZE		32768
-#define CFG_CACHELINE_SIZE	32
-#if defined(CONFIG_CMD_KGDB)
-#define CFG_CACHELINE_SHIFT	5	/*log base 2 of the above value	*/
-#endif
-
 /*
  * Internal Definitions
  *
@@ -473,7 +468,7 @@
 	"update=protect off fffc0000 ffffffff;era fffc0000 ffffffff;"	\
 		"cp.b 100000 fffc0000 40000;"			        \
 		"setenv filesize;saveenv\0"				\
-	"upd=run load;run update\0"					\
+	"upd=run load update\0"						\
 	""
 #define CONFIG_BOOTCOMMAND	"run flash_self"
 
